@@ -10,9 +10,6 @@ from inspect import isawaitable
 
 from xtyping import Any, Awaitable, Callable, Optional, ParamSpec, TypeVar, Union, cast
 
-AnyCallable = Callable[..., Any]
-FuncType = Callable[..., Any]
-
 P = ParamSpec("P")
 T = TypeVar("T")
 
@@ -69,14 +66,51 @@ def asyncify(funk: Callable[P, T]) -> Callable[P, Awaitable[T]]:
     return cast(Callable[P, Awaitable[T]], _async_funk)
 
 
-def run(aw: Awaitable[T]) -> T:
+def _run(aw: Awaitable[T], *, debug: Optional[bool] = None) -> T:
     """Run an async/awaitable function (Polyfill asyncio.run)
 
     Emulate `asyncio.run()` for snakes below python 3.7; `asyncio.run` was
     added in python3.7.
 
+    Args:
+        aw (Awaitable[T]): Async/awaitable function to run
+        debug (Optional[bool]): If True run event loop in debug mode
+
     Returns:
-        Return the result of running the async function
+        T: Return the result of running the async function
+
+    Examples:
+        >>> async def add(a, b):
+        ...     return a + b
+        ...
+        >>> from asyncify.core import _run
+        >>> _run(add(1, 4))
+        5
+
+    """
+    loop = asyncio.new_event_loop()
+    asyncio.set_event_loop(loop)
+    try:
+        if debug is not None:
+            loop.set_debug(debug)  # pragma: no cover
+        return loop.run_until_complete(aw)
+    finally:
+        loop.close()
+        asyncio.set_event_loop(None)
+
+
+def run(aw: Awaitable[T], *, debug: Optional[bool] = None) -> T:
+    """Run an async/awaitable function (Polyfill asyncio.run)
+
+    Emulate `asyncio.run()` for snakes below python 3.7; `asyncio.run` was
+    added in python3.7.
+
+    Args:
+        aw (Awaitable[T]): Async/awaitable function to run
+        debug (Optional[bool]): If True run event loop in debug mode
+
+    Returns:
+        T: Return the result of running the async function
 
     Examples:
         >>> async def add(a, b):
@@ -88,15 +122,8 @@ def run(aw: Awaitable[T]) -> T:
 
     """
     if sys.version_info >= (3, 7):
-        return asyncio.run(aw)
-
-    loop = asyncio.new_event_loop()
-    asyncio.set_event_loop(loop)
-    try:
-        return loop.run_until_complete(aw)
-    finally:
-        loop.close()
-        asyncio.set_event_loop(None)
+        return asyncio.run(aw, debug=debug)
+    return _run(aw=aw, debug=debug)  # pragma: no cover
 
 
 def is_async(obj: Any) -> bool:
@@ -108,9 +135,30 @@ def is_async(obj: Any) -> bool:
     Returns:
         bool: True if the object is async/awaitable; False otherwise
 
+    Examples:
+        >>> from asyncify import is_async
+        >>> def add(a, b): return a + b
+        >>> is_async(add)
+        False
+        >>> async def add_(a, b): return a + b
+        >>> is_async(add_)
+        True
+
     """
     return asyncio.iscoroutinefunction(obj) or asyncio.iscoroutine(obj)
 
 
 async def await_or_return(obj: Union[Awaitable[T], T]) -> T:
+    """Return the result of an awaitable or return the object
+
+    Examples:
+        >>> from asyncify import await_or_return, run
+        >>> def add(a, b): return a + b
+        >>> run(await_or_return(add(1, 4)))
+        5
+        >>> async def add_(a, b): return a + b
+        >>> run(await_or_return(add_(1, 4)))
+        5
+
+    """
     return await obj if isawaitable(obj) else obj  # type: ignore
